package at.ac.uibk.gitsearch.repository.jpa;

import at.ac.uibk.gitsearch.domain.Statistics;
import java.util.List;
import java.util.Optional;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

/**
 * Spring Data  repository for the Statistics entity.
 */
@Repository
public interface StatisticsRepository extends JpaRepository<Statistics, Long> {
    Optional<Statistics> findByExerciseID(String id);

    @Query(value = "SELECT SUM(u.views) FROM statistics u WHERE u.exercise_id IN (?1)", nativeQuery = true)
    Optional<Integer> findNumberOfViewsByExerciseIDs(List<String> list);

    @Query(value = "SELECT SUM(u.downloads) FROM statistics u WHERE u.exercise_id IN (?1)", nativeQuery = true)
    Optional<Integer> findNumberOfDownloadsByExerciseIDs(List<String> list);

    @Query(value = "SELECT SUM(u.downloads), SUM(u.views) FROM statistics u WHERE u.exercise_id IN (?1)", nativeQuery = true)
    List<Integer[]> findNumberOfDownloadsAndViewsByExerciseIDs(List<String> list);

    @Query(value = "SELECT COUNT(u.exercise_id) FROM watch_list_entry u where exercise_id = ?1", nativeQuery = true)
    Integer findNumberOfWatchListEntriesByExerciseID(String exerciseID);
}
