import { ComponentFixture, TestBed, fakeAsync, tick } from '@angular/core/testing';
import { HttpResponse } from '@angular/common/http';
import { FormBuilder } from '@angular/forms';
import { of } from 'rxjs';

import { GitsearchTestModule } from '../../../test.module';
import { UserWatchListUpdateComponent } from 'app/entities/user-watch-list/user-watch-list-update.component';
import { UserWatchListService } from 'app/entities/user-watch-list/user-watch-list.service';
import { UserWatchList } from 'app/shared/model/user-watch-list.model';

describe('Component Tests', () => {
  describe('UserWatchList Management Update Component', () => {
    let comp: UserWatchListUpdateComponent;
    let fixture: ComponentFixture<UserWatchListUpdateComponent>;
    let service: UserWatchListService;

    beforeEach(() => {
      TestBed.configureTestingModule({
        imports: [GitsearchTestModule],
        declarations: [UserWatchListUpdateComponent],
        providers: [FormBuilder],
      })
        .overrideTemplate(UserWatchListUpdateComponent, '')
        .compileComponents();

      fixture = TestBed.createComponent(UserWatchListUpdateComponent);
      comp = fixture.componentInstance;
      service = fixture.debugElement.injector.get(UserWatchListService);
    });

    describe('save', () => {
      it('Should call update service on save for existing entity', fakeAsync(() => {
        // GIVEN
        const entity = new UserWatchList(123);
        spyOn(service, 'update').and.returnValue(of(new HttpResponse({ body: entity })));
        comp.updateForm(entity);
        // WHEN
        comp.save();
        tick(); // simulate async

        // THEN
        expect(service.update).toHaveBeenCalledWith(entity);
        expect(comp.isSaving).toEqual(false);
      }));

      it('Should call create service on save for new entity', fakeAsync(() => {
        // GIVEN
        const entity = new UserWatchList();
        spyOn(service, 'create').and.returnValue(of(new HttpResponse({ body: entity })));
        comp.updateForm(entity);
        // WHEN
        comp.save();
        tick(); // simulate async

        // THEN
        expect(service.create).toHaveBeenCalledWith(entity);
        expect(comp.isSaving).toEqual(false);
      }));
    });
  });
});
